Function flate::deflate_bytesUnstable
[-] [+]
[src]
pub fn deflate_bytes(bytes: &[u8]) -> Bytes
Compress a buffer, without writing any sort of header on the output.
pub fn deflate_bytes(bytes: &[u8]) -> Bytes
Compress a buffer, without writing any sort of header on the output.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).