Function flate::deflate_bytes_zlibUnstable
[-] [+]
[src]
pub fn deflate_bytes_zlib(bytes: &[u8]) -> Bytes
Compress a buffer, using a header that zlib can understand.
pub fn deflate_bytes_zlib(bytes: &[u8]) -> Bytes
Compress a buffer, using a header that zlib can understand.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).