Function flate::inflate_bytesUnstable
[-] [+]
[src]
pub fn inflate_bytes(bytes: &[u8]) -> Result<Bytes, Error>
Decompress a buffer, without parsing any sort of header on the input.
pub fn inflate_bytes(bytes: &[u8]) -> Result<Bytes, Error>
Decompress a buffer, without parsing any sort of header on the input.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).