Function flate::inflate_bytes_zlibUnstable
[-] [+]
[src]
pub fn inflate_bytes_zlib(bytes: &[u8]) -> Result<Bytes, Error>
Decompress a buffer that starts with a zlib header.
pub fn inflate_bytes_zlib(bytes: &[u8]) -> Result<Bytes, Error>
Decompress a buffer that starts with a zlib header.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).