Struct flate::ErrorUnstable
[-] [+]
[src]
pub struct Error {
// some fields omitted
}pub struct Error {
// some fields omitted
}impl Debug for Errorimpl PartialOrd for Errorfn partial_cmp(&self, __arg_0: &Error) -> Option<Ordering>fn lt(&self, __arg_0: &Error) -> boolfn le(&self, __arg_0: &Error) -> boolfn gt(&self, __arg_0: &Error) -> boolfn ge(&self, __arg_0: &Error) -> boolimpl PartialEq for Errorimpl Ord for Errorimpl Hash for Errorfn hash<__H: Hasher>(&self, __arg_0: &mut __H)fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasherimpl Eq for Errorimpl Clone for Errorfn clone(&self) -> Errorfn clone_from(&mut self, source: &Self)
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).